HighlightedDragTarget<T extends GroupBase> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- HighlightedDragTarget
Constructors
-
HighlightedDragTarget({required Widget child, required Parent<
T> ? parent, required DragTargetWillAccept<Parent< onWillAccept, Key? key, dynamic onAccept(Parent<T> >T> source, T? destination)?, Border? initialBorder, Border? highlightedBorder}) -
const
Properties
- child → Widget
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlightedBorder → Border?
-
Assigned this value to one of
borderswhen a dragged piece is over a widget.final - initialBorder → Border?
-
Assigned this value to one of
borderswhen a dragged piece leaves a target, is accepted or rejected.final - key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onAccept
→ dynamic Function(Parent<
T> source, T? destination)? -
Called when an acceptable piece of
sourcedata was dropped over thisdestination.draggablemust be set to true. Nulldestinationmeans the source item wants to be top parent.sourceanddestinationare definitely different group.final -
onWillAccept
→ DragTargetWillAccept<
Parent< T> > -
Called to determine whether this widget is interested in receiving a given
piece of data being dragged over this drag target.
final
-
parent
→ Parent<
T> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → _HighlightedDragTarget< T> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited